@@ -40,7 +40,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.03;
+    our $VERSION = 1.04;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -410,6 +410,7 @@ sub new {
         'Path'               => '/var/log',                           # Default path should type be unix
         'FileHandle'         => \*STDERR,                             # Default filehandle is STDERR
         'MasterStart'        => $MASTERSTART,                         # Pull in the script start timestamp
+        'ANY_LastStamp'      => time,                                 # Initialize main benchmark
         'ERR_LastStamp'      => time,                                 # Initialize the ERR benchmark
         'WARN_LastStamp'     => time,                                 # Initialize the WARN benchmark
         'INFO_LastStamp'     => time,                                 # Initialize the INFO benchmark
@@ -420,8 +421,10 @@ sub new {
         'Color'              => TRUE,                                 # Default to colorized output
         'DateStamp'          => colored(['yellow on_black'], '%date%'),
         'TimeStamp'          => colored(['yellow on_black'], '%time%'),
-        'Padding'            => -15,                                  # Default padding is 15 spaces
+        'Padding'            => -20,                                  # Default padding is 20 spaces
         'CPadding'           => -2,
+        'SPadding'           => 0,
+        'LPadding'           => 0,
         'Prefix'             => '%Date% %Time% %Benchmark% %Loglevel%[%Subroutine%][%Lastline%] ',
         'DEBUGMAX-Prefix'    => '%Date% %Time% %Benchmark% %Loglevel%[%Module%][%Lines%] ',
         'Filename'           => '[' . colored(['magenta'],$filename) . ']',
@@ -431,7 +434,7 @@ sub new {
             'NOTICE'    => colored(['yellow'],              '[NOTICE ]'),
             'INFO'      => colored(['black on_white'],      '[ INFO  ]'),
             'DEBUG'     => colored(['bold green'],          '[ DEBUG ]'),
-            'DEBUGMAX'  => colored(['bold black on_green'], '[-DEBUG-]'),
+            'DEBUGMAX'  => colored(['bold black on_green'], '[DEBUGMX]'),
         },
         @_
     };
@@ -454,7 +457,7 @@ sub new {
 
     # This instructs the ANSIColor library to turn off coloring,
     # if the Color attribute is set to zero.
-    $ENV{'ANSI_COLORS_DISABLED'} = TRUE if ($self->{'COLOR'} =~ /0|FALSE|OFF/i);
+    $ENV{'ANSI_COLORS_DISABLED'} = TRUE if ($self->{'COLOR'} =~ /0|FALSE|OFF|NO/i);
 
     # If COLOR is FALSE, then clear color data from ANSILEVEL, as these were
     # defined before color was turned off.
@@ -464,8 +467,8 @@ sub new {
         'NOTICE'    => '[NOTICE ]',
         'INFO'      => '[ INFO  ]',
         'DEBUG'     => '[ DEBUG ]',
-        'DEBUGMAX'  => '[-DEBUG-]',
-    } if ($self->{'COLOR'} =~ /0|FALSE|OFF/i);
+        'DEBUGMAX'  => '[DEBUGMX]',
+    } if ($self->{'COLOR'} =~ /0|FALSE|OFF|NO/i);
     %ANSILevel = %{$self->{'ANSILEVEL'}};
 
     foreach my $lvl (@Levels) {
@@ -520,7 +523,7 @@ sub debug {
     my $msgs  = shift;
 
     if ($level !~ /ERR.*|WARN.*|NOTICE|INFO.*|DEBUG/i) { # Compatibility with older versions.
-        $level = $msgs;                                  # It tosses the __LINE__ argument
+        $level = $msgs;                                  # It tosses the legacy __LINE__ argument
         $msgs  = shift;
     }
     $level = 'ERR'  if ($level eq 'ERROR');      # This allows the programmer to use either
@@ -605,7 +608,7 @@ sub debug {
         $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{'ANY_LASTSTAMP'}));
         $thisBench2 = ' ' x length($thisBench);
     }
-    my $first = 1;                         # Set the first line flag.
+    my $first = TRUE;                      # Set the first line flag.
     foreach my $msg (@messages) {          # Loop through each line of output and format accordingly.
         if (ref($msg) ne '') {
             if ($Modules->{'Data::Printer'}) {
@@ -622,18 +625,18 @@ sub debug {
             my @message = split(/\n/, $msg);
             foreach my $line (@message) {  # Loop through the split lines and format accordingly.
                 $self->_send_to_logger($level, $nested, $line, $first, $thisBench, $thisBench2, $subroutine, $cline,$sline,$short);
-                $first = 0;                # Clear the first line flag.
+                $first = FALSE;            # Clear the first line flag.
             }
         } else {                           # This line does not contain newlines.  Treat it as a single line.
             $self->_send_to_logger($level, $nested, $msg, $first, $thisBench, $thisBench2, $subroutine, $cline,$sline,$short);
         }
-        $first = 0;                        # Clear the first line flag.
+        $first = FALSE;                    # Clear the first line flag.
     }
     $self->{'ANY_LASTSTAMP'}       = time;
     $self->{$level . '_LASTSTAMP'} = time;
 }
 
-sub _send_to_logger {    # This actually simplifies the previous class ... seriously
+sub _send_to_logger {    # This actually simplifies the previous object ... seriously
     my $self       = shift;
     my $level      = shift;
     my $padding    = shift;
@@ -878,7 +881,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.03    (July 10, 2015 Happy Birthday to me!)
+Version 1.04    (July 10, 2015 Happy Birthday to me!)
 
 =head1 BUGS
 
